title: #2: Ten days later
date: 2023-11-05 09:00
author: tundish
tags: python, balladeer, game jam
category: Blog
status: published
summary: For a moment, nothing happened.

Hesitation
----------

It was Wednesday before I wrote any code.

There had been scant opportunity to do so, and in any case, I did not know where to start.
Instead, over the first few days there started to form in my mind's eye a flicker of an opening
sequence. Rhythmic, like a scene from a road movie. The darkened profile of a passenger from the
inside of a speeding vehicle.

A new possibility for the word *repo*. Two characters in a van on the way to a job. I began to imagine
some dialogue. Which is the player; the driver or the mate?

We have to give the player a few moments to settle in.
We want some workmanlike banter to reveal the initial premise.
Some low-stakes decisions to kick off the adventure.

That's when I realised the benefit of a [dialogue tree](https://en.wikipedia.org/wiki/Dialogue_tree).
And since at the time Balladeer didn't offer such a feature, I spent the rest of the week building one.

It was the best thing that could have happened. I'm very pleased with the new
[Interaction](https://balladeer.readthedocs.io/en/latest/interaction.html) system. So
[thankyou](https://itch.io/jam/python-game-jam-8/topic/3266238/thanks-for-hosting-the-jam-and-good-luck-to-those-hoping-to-finish)
to the Python Game Jam.
